==> gv-3.6.2.tar.gz: gv-3.6.2/src/save.h <==
/*
**
** save.h
**
** Copyright (C) 1995, 1996, 1997 Johannes Plass
** Copyright (C) 2004 Jose E. Marchesi
** 
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with GNU gv; see the file COPYING.  If not, write to
** the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
** Boston, MA 02111-1307, USA.
** 
** Author:   Johannes Plass (plass@thep.physik.uni-mainz.de)
**           Department of Physics
**           Johannes Gutenberg-University
**           Mainz, Germany
**
**           Jose E. Marchesi (jemarch@gnu.org)
**           GNU Project
**
*/

#ifndef	_GV_SAVE_H_
#define	_GV_SAVE_H_

typedef struct SaveDataStruct_ {
   char         *save_fn;
   char         *src_fn;
   char         *conv_fn;
   char         *pagelist;
   char         *print_cmd;
   int          convert;
   int          save_to_file;
   int          save_to_printer;
   int          print_kills_file;
   int          scanstyle;
} SaveDataStruct, *SaveData;

extern SaveData			save_allocSaveData (
#if NeedFunctionPrototypes
#endif
);

extern void			save_freeSaveData (
#if NeedFunctionPrototypes
   SaveData	/* sd */
#endif
);

extern String			save_saveFile (
#if NeedFunctionPrototypes
   SaveData	/* sd */
#endif
);

#endif  /* _GV_SAVE_H_ */

==> gv-3.7.3.tar.gz: gv-3.7.3/src/save.h <==
/*
**
** save.h
**
** Copyright (C) 1995, 1996, 1997 Johannes Plass
** Copyright (C) 2004 Jose E. Marchesi
** 
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with GNU gv; see the file COPYING.  If not, write to
** the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
** Boston, MA 02111-1307, USA.
** 
** Author:   Johannes Plass (plass@thep.physik.uni-mainz.de)
**           Department of Physics
**           Johannes Gutenberg-University
**           Mainz, Germany
**
**           Jose E. Marchesi (jemarch@gnu.org)
**           GNU Project
**
*/

#ifndef	_GV_SAVE_H_
#define	_GV_SAVE_H_

typedef struct SaveDataStruct_ {
   char         *save_fn;
   char         *src_fn;
   char         *conv_fn;
   char         *pagelist;
   char         *print_cmd;
   int          convert;
   int          save_to_file;
   int          save_to_printer;
   int          print_kills_file;
   int          scanstyle;
} SaveDataStruct, *SaveData;

extern SaveData save_allocSaveData (void);
extern void     save_freeSaveData  (SaveData);
extern String   save_saveFile      (SaveData);

#endif  /* _GV_SAVE_H_ */
